//
//  RecordingManager.swift
//  canary_recorder
//
//  Created by Andrew Ackerman on 8/23/18.
//

import UIKit
import AVFoundation

class RecordingManager {
    
    let recordingSettings = [
        AVFormatIDKey: Int(kAudioFormatLinearPCM),
        AVSampleRateKey: 44100,
        AVNumberOfChannelsKey: 1,
        AVLinearPCMBitDepthKey: 16,
        AVLinearPCMIsBigEndianKey: 0,
        AVEncoderAudioQualityKey: AVAudioQuality.high.rawValue
    ]
    
    var audioRecorder: AVAudioRecorder?
    var outputFile: String?
    var isRecording = false
    
    static let sharedInstance = RecordingManager()
    private init () {}
    
    func prepare(filename: String) {
        if isRecording {
            stop()
        }
        
        outputFile = filename
    }
    
    func start() {
        guard let outputFile = outputFile else { return }
        let pathSegments = outputFile.components(separatedBy: "/")
        let docDir = FileManager.default.urls(for: .documentDirectory, in: .userDomainMask)[0]
        let dir = docDir.appendingPathComponent(pathSegments.last!)
        let audioPath = dir;
        
        do {
            let audioSession = AVAudioSession.sharedInstance()
            try audioSession.setCategory(AVAudioSessionCategoryRecord)
            try audioSession.setActive(true)
            audioRecorder = try AVAudioRecorder(url: audioPath, settings: recordingSettings)
            audioRecorder?.record()
            
            isRecording = true
            print("Recording to file \(audioPath.absoluteString)")
        } catch {
            isRecording = false
            print("Error while attempting to record")
        }
    }
    
    func stop() {
        audioRecorder?.stop()
        audioRecorder = nil
        isRecording = false
    }
    
}
